@@ -1,6 +1,5 @@
 import re
-import urllib
-import cgi
+from dosage.util import fetchUrl, getQueryParams
 from dosage.modules.helpers.BasicComicModule import BasicComicModule, BounceMixin
 
 class KiagiSwordscat(BasicComicModule, BounceMixin):
@@ -12,6 +11,4 @@ class KiagiSwordscat(BasicComicModule, BounceMixin):
     help = 'Index format: yyyymmdd'
 
     def getFilename(self, imageUrl, pageUrl):
-	queryString = urllib.splitquery(pageUrl)[1]
-	attribs = cgi.parse_qs(queryString)
-	return attribs['go'][0]
+        return getQueryParams(pageUrl)['go'][0]
