@@ -3,6 +3,7 @@ import urllib
 import cgi
 from dosage.modules.helpers.BasicComicModule import BasicComicModule
 from dosage.modules.helpers.BasicComicModule import BounceMixin
+from dosage.util import getQueryParams
 
 class PiledHigherAndDeeper(BasicComicModule, BounceMixin):
     latestUrl = 'http://www.phdcomics.com/comics/archive.php'
@@ -13,7 +14,4 @@ class PiledHigherAndDeeper(BasicComicModule, BounceMixin):
     help = 'Index format: n (unpadded)'
 
     def getFilename(self, imageUrl, pageUrl):
-        print imageUrl, pageUrl
-        queryString = urllib.splitquery(pageUrl)[1]
-        attribs = cgi.parse_qs(queryString)
-        return attribs['comicid'][0]
+        return getQueryParams(pageUrl)['comicid'][0]
